Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Connection ¶ added in v1.10.7
type Connection struct {
AuthToken string
}
Connection represents the active session with the Roku API.
func NewConnection ¶ added in v1.10.7
func NewConnection(current *User) (*Connection, error)
NewConnection initializes a session. User can be nil
func (*Connection) LinkCode ¶ added in v1.10.7
func (c *Connection) LinkCode() (*LinkCode, error)
RequestLinkCode requests a new activation code from the server
type LinkCode ¶ added in v1.10.7
type LinkCode struct {
Code string
}
LinkCode represents the activation code displayed to the user.
Click to show internal directories.
Click to hide internal directories.